==> haskell-mysql-simple-0.4.9-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mysql-simple
version:              0.4.9
visibility:           public
id:                   mysql-simple-0.4.9-6I9HHUrLkR7G81Dnnm3na9
key:                  mysql-simple-0.4.9-6I9HHUrLkR7G81Dnnm3na9
license:              BSD-3-Clause
copyright:            2011 MailRank, Inc.
maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql-simple
synopsis:             A mid-level MySQL client library.
description:
    A mid-level client library for the MySQL database, intended to be
    fast and easy to use.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  c66ab26bfc4d6d2ca438ee03cd5870a5
exposed:              True
exposed-modules:
    Database.MySQL.Simple Database.MySQL.Simple.Param
    Database.MySQL.Simple.QueryParams
    Database.MySQL.Simple.QueryResults Database.MySQL.Simple.Result
    Database.MySQL.Simple.Types

hidden-modules:       Database.MySQL.Internal.Blaze
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mysql-simple
hs-libraries:         HSmysql-simple-0.4.9-6I9HHUrLkR7G81Dnnm3na9
depends:
    attoparsec-0.14.4-4svHBw0u1Cc40MQ1AjsKLc base-4.17.2.1
    base16-bytestring-1.0.2.0-DtLhCS1yMgY3iFYZkoZd12
    blaze-builder-0.4.3-9mr2QS4Ac5jKPZdkUQKEwx bytestring-0.11.5.3
    containers-0.6.7 mysql-0.2.1-Fm2sbzuZCeY9gbVgUxPeNo
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    pcre-light-0.4.1.3-KNdIDQJBMfqZw80tRO96W text-2.0.2 time-1.12.2
    vector-0.13.2.0-ZKpjTfyjPa7BNElf7Ue7Z

haddock-interfaces:
    /usr/share/doc/haskell-mysql-simple/html/mysql-simple.haddock

haddock-html:         /usr/share/doc/haskell-mysql-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mysql-simple-0.4.9-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mysql-simple
version:              0.4.9
visibility:           public
id:                   mysql-simple-0.4.9-alLLhxgmZH3QlhlNoNkcQ
key:                  mysql-simple-0.4.9-alLLhxgmZH3QlhlNoNkcQ
license:              BSD-3-Clause
copyright:            2011 MailRank, Inc.
maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql-simple
synopsis:             A mid-level MySQL client library.
description:
    A mid-level client library for the MySQL database, intended to be
    fast and easy to use.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  dd032548dc38b6a7ebd2a7f82ce87bd3
exposed:              True
exposed-modules:
    Database.MySQL.Simple Database.MySQL.Simple.Param
    Database.MySQL.Simple.QueryParams
    Database.MySQL.Simple.QueryResults Database.MySQL.Simple.Result
    Database.MySQL.Simple.Types

hidden-modules:       Database.MySQL.Internal.Blaze
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mysql-simple
hs-libraries:         HSmysql-simple-0.4.9-alLLhxgmZH3QlhlNoNkcQ
depends:
    attoparsec-0.14.4-fEKSJrOU814GdIIzzkkyx base-4.17.2.1
    base16-bytestring-1.0.2.0-AruU1abSL9kB4FwSdXdpL1
    blaze-builder-0.4.3-BgDmm9LLPQj70kDL41wf1H bytestring-0.11.5.3
    containers-0.6.7 mysql-0.2.1-BfNyBds0I0FDTSqIkTUMEI
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    pcre-light-0.4.1.3-KNdIDQJBMfqZw80tRO96W text-2.0.2 time-1.12.2
    vector-0.13.2.0-GjxrA8HCtQq4MGRlxeWifh

haddock-interfaces:
    /usr/share/doc/haskell-mysql-simple/html/mysql-simple.haddock

haddock-html:         /usr/share/doc/haskell-mysql-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
